@@ -96,6 +96,7 @@ int main(int argc,char *argv[])
   if ( ret != XNEE_OK)
     {
       cnee_handle_err(ret);
+      return ret;
     }
 
   if (ret==XNEE_OK)
@@ -107,13 +108,14 @@ int main(int argc,char *argv[])
   if ( ret != XNEE_OK)
   {
     cnee_handle_err(ret);
+    return ret;
   }
 
   /* hey, we are fin(n)ished .... close down */
   xnee_close_down(xd);
   
   /* Since we are here, we can exit gracefully */
-  exit(XNEE_OK); 
+  exit(ret); 
 }
 
 
