@@ -5,7 +5,7 @@
  *                                                                   
  *        Copyright (C) 1999, 2000, 2001, 2002, 2003 
  *                      2004, 2005, 2006, 2007, 2008
- *                      2009, 2010  Henrik Sandklef                    
+ *                      2009, 2010, 2011  Henrik Sandklef                    
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -299,6 +299,9 @@ xnee_get_all_clients (xnee_data *xd);
 int
 xnee_is_future_clients_str(xnee_data *xd);
 
+int
+xnee_is_future_clients (xnee_data *xd);
+
 int
 xnee_is_all_clients (xnee_data *xd);
  
@@ -605,6 +608,9 @@ xnee_get_new_window_pos (xnee_data *xd);
 int
 xnee_get_new_window_pos_value (xnee_data *xd);
 
+int
+xnee_set_new_window_pos_value (xnee_data *xd, int val);
+
 int
 xnee_unset_new_window_pos (xnee_data *xd);
 
@@ -875,4 +881,7 @@ xnee_set_forced_core_device_events(xnee_data *xd);
 int
 xnee_unset_forced_core_device_events(xnee_data *xd);
 
+int
+xnee_is_forced_core_device_events(xnee_data *xd);
+
 #endif /* XNEE_SETGET_H */ 
