@@ -3,7 +3,7 @@
  *                                                                   
  * Xnee enables recording and replaying of X protocol data           
  *                                                                   
- *   Copyright (C) 2010, 2011       Henrik Sandklef 
+ *   Copyright (C) 2010, 2011, 2012     Henrik Sandklef 
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -75,8 +75,16 @@ xnee_init_xinput_devices(xnee_data *xd)
   if (XIQueryVersion(xd->control, &major, &minor) != Success ||
       (major * 1000 + minor) < (XI_2_Major * 1000 + XI_2_Minor))
     {
-      fprintf(stderr, "XI2 not supported.\n");
-      return EXIT_FAILURE;
+      if (major  < XI_2_Major )
+	{
+	  fprintf(stderr, "XI2 not supported\n");
+	  return EXIT_FAILURE;
+	}
+      else
+	{
+	  fprintf(stderr, "XI2 may not be supported (minor: %d/%d)\n", 
+		  minor, XI_2_Minor);
+	}
     }
 
   xi_info = XIQueryDevice(xd->control, XIAllDevices, &nr_of_devices);
@@ -162,10 +170,10 @@ xnee_get_xinput_event_base(Display *dpy)
   int ext_op;
   static int ext_fi_ev = 0 ;
   int ext_fi_er;
-  
+
   if ( ext_fi_ev == 0)
     {
-
+      
       if ( dpy == NULL )
 	{
 	  dpy = XOpenDisplay(NULL);
@@ -185,7 +193,7 @@ xnee_get_xinput_event_base(Display *dpy)
 	}
     }
   return ext_fi_ev;
-    }
+}
 
 
 int
@@ -228,6 +236,7 @@ xnee_handle_xinput_event(xnee_data * xd,
 
   out = xd->out_file;
   
+  /* printf ("\nXI HE base=%d   event_type=%d  last:%d  \n",xd->xi_data.xinput_event_base, event_type, sxe.type);   */
 
   /*
    * Are we using Xinput
@@ -242,7 +251,7 @@ xnee_handle_xinput_event(xnee_data * xd,
       deviceKeyButtonPointer *e;
       e = (deviceKeyButtonPointer *) &xrec_data->event ;
       
-      xnee_verbose((xd, "handle xi:: dev-id%d type:%d  ", 
+    xnee_verbose((xd, "handle xi:: dev-id%d type:%d  ", 
 		    e->deviceid,
 		    event_type));
       ordinary_event_nr = event_type - xd->xi_data.xinput_event_base + 1;
@@ -312,7 +321,6 @@ xnee_handle_xinput_event(xnee_data * xd,
     }
   else if ( event_type == xd->xi_data.xinput_event_base)
     {
-      
       /*
        *
        *  DaviceValuator event
@@ -337,9 +345,10 @@ xnee_handle_xinput_event(xnee_data * xd,
 	}
       valuator_counter = 0 ;
 
+
+
       if ( sxe.type == MotionNotify )
 	{
-	 
 	  XNEE_XINPUT_PRINT_MASTER_OR_SLAVE(xd, e->deviceid, out);
 	  fprintf (out, ",%d,%d,%d,0,0,0,%lu,%d,'%s'\n",
 		   sxe.type,
@@ -356,7 +365,7 @@ xnee_handle_xinput_event(xnee_data * xd,
 	{
 	  fprintf (stderr, 
 		   "WARNING: Enough valuators,"
-		   "but non motion/button event so not printing\n");      
+		   "but non motion/button event (%d) so not printing\n", sxe.type);      
 	  return -1;
 	}
       sxe.x = 0;
@@ -520,7 +529,7 @@ xnee_xinput_add_devices(xnee_data *xd)
   else if ( xnee_xinput_keyboard_requested(xd))
     {
       snprintf(buf, XI_BUF_SIZE, "%d-%d", 
-	      xinput_ev_base,
+	      xinput_ev_base+1,
 	      xinput_ev_base+2);
     }
 
